/******************************
 * The Fredericks Company
 * www.frederickscompany.com
 * sales@frederickscompany.com
 *
 * RS-232 Arduino Communication
 * 
 * Code for Arduino Uno to read tilt and temperature from
 * a sensor mounted on the 1-6200-006 signal conditioner
 * using an RS-232 signal.
 * 
 * Output: print X, Y, and Temperature to serial port every 1 second
 *
 * Rev -
 * 
 * */

#include <SoftwareSerial.h>

#define RXPIN 10 // define pin 10 as receive
#define TXPIN 11 // define pin 11 as transmit

SoftwareSerial Sensor(RXPIN, TXPIN, true); // initialize the software serial port transmit and receive pins and set inverse to true

void setup() {
    Serial.begin(9600); // set the baud rate for the Arduino serial communication
    while(!Serial);
    Serial.println("Starting RS-232");
    Sensor.begin(9600); // set the baud rate for the 1-6200-006 communication
    while(!Sensor);
    Serial.println("RS-232 port opened");
}

void loop() {
    char output[3][9]; // define a 2D char array for the output (this will store 3 rows of values for x, y, & t)
    char commands[3] = {'x', 'y', 't'}; // define a char array with the commands
    int b = 0;

    for (int i = 0; i < 3; i++) {
        b = 0;
        Sensor.print(commands[i]); // send all the commands to the sensor
        delay(50);
        while (Sensor.available() != 0 && b < 8) {
            output[i][b++] = Sensor.read(); // store the response for each command in the output array
        }
        output[i][b - 2] = '\0'; // null character termination for string
    }

    // print the output to the Serial Monitor
    Serial.print("X: "); 
    Serial.println(output[0]);
    Serial.print("Y: ");
    Serial.println(output[1]);
    Serial.print("T: ");
    Serial.println(output[2]);

    Serial.println("\n");

    delay(1000);
}

